@@ -2,13 +2,21 @@
 #include <ranges>
 #include <filesystem>
 
+#ifdef _WIN32
+#include <windows.h>
+#endif
+
 #include "options.h"
 #include "help.h"
 #include "net.h"
 
 
-int main(int argc, char *argv[])
-{
+int main(int argc, char *argv[]) {
+#ifdef _WIN32
+    SetConsoleOutputCP(CP_UTF8);
+    SetConsoleCP(CP_UTF8);
+#endif
+
     if (argc == 1) {
         Help::showHelp("--help");
         return 0;
