@@ -5,8 +5,8 @@
 
 #include <curl/curl.h>
 
-#include "libJSONHandle/include/escape.h"
-#include "libJSONHandle/include/dataquery.h"
+#include "libJSONHandle/include/format_handling.h"
+#include "libJSONHandle/include/data_handling.h"
 
 
 std::expected<std::string, std::string> Net::aiDispatcher(
@@ -19,9 +19,9 @@ std::expected<std::string, std::string> Net::aiDispatcher(
     ) {
     std::tuple<std::string, std::vector<std::string>, std::string> apiParameters;
 
-    connectionRoleInstruction = Escape::escapeCharacters(connectionRoleInstruction);
-    connectionDetailedInstructions = Escape::escapeCharacters(connectionDetailedInstructions);
-    connectionContent = Escape::escapeCharacters(connectionContent);
+    connectionRoleInstruction = FormatHandling::escapeCharacters(connectionRoleInstruction);
+    connectionDetailedInstructions = FormatHandling::escapeCharacters(connectionDetailedInstructions);
+    connectionContent = FormatHandling::escapeCharacters(connectionContent);
 
     std::string apiReplyQueryCondition;
     std::string apiReplyQuery;
@@ -94,25 +94,39 @@ std::expected<std::string, std::string> Net::aiDispatcher(
              * Here apiReplyQueryCondition may be replaced with an empty string "",
              * because the combination of query keys is unique.
              */
+            bool queryState = false;
             std::pair<std::string, std::string> replyPair;
-            replyPair = DataQuery::dataQuery(
+
+            auto queryResult = DataHandling::dataQuery(
                 replyJSON, apiReplyQuery, apiReplyQueryCondition
             );
 
-            /* If the query gets no result, the program tries to make a query
-             * for error information.
+            queryState = std::get<0>(queryResult);
+            replyPair = std::get<1>(queryResult);
+
+            /* If the value of queryState is false, it means that the given key path
+             * is not found during the query to the JSON text of AI's reply.
+             * Accordingly, the program tries to make a query for error information.
              */
-            if (replyPair.second.empty()) {
-                replyPair = DataQuery::dataQuery(
+            if (!queryState) {
+                queryResult = DataHandling::dataQuery(
                     replyJSON, apiReplyErrorInfo, ""
                 );
+                queryState = std::get<0>(queryResult);
+                replyPair = std::get<1>(queryResult);
             }
 
-            /* Before the text is shown to the user, the program restores
-             * newline characters \n and double quotation marks " from their
-             * escaped characters.
-             */
-            std::string replyText = Escape::parseCharacters(replyPair.second);
+            std::string replyText;
+
+            if (queryState) {
+                /* Before the text is shown to the user, the program restores
+                 * newline characters \n and double quotation marks " from their
+                 * escaped characters.
+                 */
+                replyText = FormatHandling::parseCharacters(replyPair.second);
+            } else {
+                replyText = "No result is found for the query to the JSON text of AI's reply.";
+            }
 
             return replyText;
         }
@@ -209,7 +223,7 @@ Net::prepareClaudeParameters(
     std::ostringstream jsonQuery;
     jsonQuery << '{'
                 << '"' << "model"      << '"' << ": " << '"' << connectionModel << '"' << ", "
-                << '"' << "max_tokens" << '"' << ": " << 1000 << ", "
+                << '"' << "max_tokens" << '"' << ": " << 1200 << ", "
                 << '"' << "messages"   << '"' << ": " << '['
                   << '{'
                     << '"' << "role"    << '"' << ": " << '"' << "user" << '"' << ", "
@@ -259,6 +273,10 @@ Net::getReply(
     ) {
     CURL *curl = curl_easy_init();
     if (curl) {
+#ifdef _WIN32
+        curl_easy_setopt(curl, CURLOPT_CAINFO, "curl-ca-bundle.crt");
+#endif
+
         auto [apiUrl, apiHeaders, jsonQuery] = apiParameters;
 
         curl_easy_setopt(curl, CURLOPT_URL, apiUrl.c_str());
